@@ -1,8 +1,10 @@
+#[cfg(feature = "config")]
+pub mod config;
 #[cfg(feature = "dialogs")]
 pub mod dialogs;
 pub mod parse;
 mod run;
-#[cfg(feature = "config")]
-pub mod config;
 pub mod timing;
 pub use run::Run;
+mod instant;
+pub use instant::MistInstant;
